TODO: Add requiresments for building docs.

To build the docs, install the needed requirements, then run

    make doctest
    make html
    
Then the docs will be available at `_build/html/index.html`.
